@@ -716,6 +716,13 @@ void AbstractByteArrayColumnRendererPrivate::renderCursor(QPainter* painter, Add
         mByteTypeColored ? foregroundRoleForChar(byteChar) : KColorScheme::NormalText;
     const QBrush brush = colorScheme.foreground(foregroundRole);
     painter->fillRect(0, 0, mByteWidth, q->lineHeight(), brush);
+
+    const bool isBookmark = (byteIndex > -1 && mBookmarks && mBookmarks->containsBookmarkFor(byteIndex));
+    const KColorScheme::BackgroundRole backgroundRole =
+        isBookmark ? KColorScheme::NeutralBackground : KColorScheme::NormalBackground;
+    const QBrush charBrush = colorScheme.background(backgroundRole);
+    const QColor& charColor = charBrush.color();
+    renderByteText(painter, byte, byteChar, charColor);
 }
 
 bool AbstractByteArrayColumnRendererPrivate::getNextSelectedAddressRange(AddressRange* _selection, unsigned int* _flag,
